@@ -70,8 +70,8 @@ end
 def boilerplate(key)
   ret = ''
   case key.downcase
-  when /\Abcp14(info)?(\+)?(-tagged)?(-bcp)?\z/i
-    #            $1    $2     $3       $4
+  when /\Abcp14(info)?(\+)?(-tagged)?(-bcp(14)?)?\z/i
+    #            $1    $2     $3       $4  $5
     if $1
       ret << <<RFC8174ise
 Although this document is not an IETF Standards Track publication, it
@@ -110,11 +110,19 @@ PLUS
 TAGGED
     end
     if $4                       # experimental; idnits complains:
+      if $5
+      #  ** The document contains RFC2119-like boilerplate, but doesn't seem to
+      #     mention RFC 2119.  The boilerplate contains a reference [BCP14], but that
+      #     reference does not seem to mention RFC 2119 either.
+        ret.sub!("BCP 14 {{!RFC2119}} {{!RFC8174}}",
+                 "{{!BCP14}} ({{RFC2119}}) ({{RFC8174}})")
+      else
       #  ** The document seems to lack a both a reference to RFC 2119 and the
       #     recommended RFC 2119 boilerplate, even if it appears to use RFC 2119
       #     keywords -- however, there's a paragraph with a matching beginning.
       #     Boilerplate error?
-      ret.sub!("{{!RFC2119}} {{!RFC8174}}", "{{!BCP14}}")
+        ret.sub!("{{!RFC2119}} {{!RFC8174}}", "{{!BCP14}}")
+      end
     end
     ret
   when /\Arfc\s*7942(info)?\z/i
@@ -260,6 +268,13 @@ end
 
 include ::Kramdown::Utils::Html
 
+# Make this a method so there is a more speaking traceback if this fails
+def read_erbfile
+  erbfilename = ENV["KRAMDOWN_ERB_FILE"] ||
+                File.expand_path('../../../data/kramdown-rfc2629.erb', __FILE__)
+  File.read(erbfilename, coding: "UTF-8")
+end
+
 def xml_from_sections(input)
 
   unless ENV["KRAMDOWN_NO_SOURCE"]
@@ -281,6 +296,12 @@ def xml_from_sections(input)
   # the first section is a YAML with front matter parameters (don't put a label here)
   # We put back the "---" plus gratuitous blank lines to hack the line number in errors
   yaml_in = input[/---\s*/] << sections.shift[2]
+  begin
+    require 'kramdown-rfc/yamlcheck'
+    KramdownRFC::YAMLcheck.check_dup_keys(yaml_in)
+  rescue => e
+    warn "** Cannot check for duplicate keys in YAML header (#{e})"
+  end
   ps = KramdownRFC::ParameterSet.new(yaml_load(yaml_in, [Date], [], true))
 
   if v = ps[:v]
@@ -376,6 +397,7 @@ def xml_from_sections(input)
     v.gsub!(/{{(#{
       spacify_re(XSR_PREFIX)
     })?([\w.\/_\-]+@)?(?:([?!])(-)?|(-))([\w._\-]+)(?:=([\w.\/_\-]+))?(#{
+    #  2                 3     4    5   6              7
       XREF_TXT_SUFFIX
     })?(#{
       spacify_re(XSR_SUFFIX)
@@ -421,8 +443,9 @@ def xml_from_sections(input)
 
   norm_ref.each do |k, v|
     # could check bibtagsys here: needed if open_refs is nil or string
-    target = ps.has(v ? :normative : :informative)
-    warn "*** overwriting #{k}" if target.has_key?(k)
+    kind = v ? :normative : :informative
+    target = ps.has(kind)
+    warn "** (#{kind} reference #{k} is both inline and in YAML header)" if target.has_key?(k)
     target[k] = open_refs[k] # add reference to normative/informative
   end
   # note that unused items from ref are considered OK, therefore no check for that here
@@ -459,8 +482,29 @@ def xml_from_sections(input)
             sechash[sn.to_s] << %{&#{bts};\n} # ???
           end
         else
+          if v.nil? && (bri = bibref.to_i) != 0
+            v = bri
+          end # hack in {{?Err6543=8610}}
+          if v && Integer === v
+            case href
+            when /\AErr(.*)/
+              epno = $1
+              rfcno = v.to_s
+              v = {
+                "target" => "https://www.rfc-editor.org/errata/eid#{epno}",
+                "title" => "RFC Errata Report #{epno}",
+                "quote-title" => false,
+                "seriesinfo" => { "RFC" => rfcno },
+                "date" => false
+              }
+            else
+              # superfluous -- would be caught by next "unless"
+              warn "*** don't know how to expand numeric ref #{k}"
+              next
+            end
+          end
           unless v && Hash === v
-            warn "*** don't know how to expand ref #{k}"
+            warn "*** don't know how to expand ref #{k} #{v.inspect}"
             next
           end
           if bts && !v.delete("override")
@@ -473,8 +517,7 @@ def xml_from_sections(input)
     end
   end
 
-  erbfilename = File.expand_path '../../../data/kramdown-rfc2629.erb', __FILE__
-  erbfile = File.read(erbfilename, coding: "UTF-8")
+  erbfile = read_erbfile
   erb = ERB.trim_new(erbfile, '-')
   # remove redundant nomarkdown pop outs/pop ins as they confuse kramdown
   input = erb.result(binding).gsub(%r"{::nomarkdown}\s*{:/nomarkdown}"m, "")
