@@ -32,6 +32,7 @@ class Object
 end
 
 module Kramdown
+  RFCXML_SPAN_ELEMENTS = Set.new(Kramdown::Parser::Html::Constants::HTML_SPAN_ELEMENTS)
 
   Kramdown::Options.define(:ol_start_at_first_marker, Kramdown::Options::Boolean, false, <<~EOF)
       If this option is `true`, an ordered list (<ol) will use the
@@ -368,7 +369,7 @@ module Kramdown
       if KRAMDOWN_PERSISTENT
         begin
           require 'net/http/persistent'
-          $http = Net::HTTP::Persistent.new name: 'kramdown-rfc'
+          $http = Net::HTTP::Persistent.new name: 'kramdown-rfc', proxy: :ENV
         rescue Exception => e
           warn "** Not using persistent HTTP -- #{e}"
           warn "**   To silence this message and get full speed, try:"
@@ -620,11 +621,23 @@ COLORS
           outpath = file.path + ".svg"
           result1 = File.read(outpath) rescue '' # don't die before providing error message
           File.unlink(outpath) rescue nil        # ditto
-        when "plantuml", "plantuml-utxt"
+        when "plantuml", "plantuml-utxt", "plantuml-ascii-art"
+          if t == "plantuml-ascii-art"
+            result, ascii_art = result.split(/^~{3,} ascii-art\n/, 2)
+            unless ascii_art
+              warn "*** Didn't find ascii-art in plantuml-ascii-art #{result.inspect}"
+              ascii_art = result.to_s
+            end
+          end
           plantuml = "@startuml\n#{result}\n@enduml"
           result1, err, _s = Open3.capture3("plantuml -pipe -tsvg#{svg_opt}", stdin_data: plantuml);
-          result, err1, _s = Open3.capture3("plantuml -pipe -tutxt#{txt_opt}", stdin_data: plantuml) if t == "plantuml-utxt"
-          err << err1.to_s
+          case t
+          when "plantuml-utxt"
+            result, err1, _s = Open3.capture3("plantuml -pipe -tutxt#{txt_opt}", stdin_data: plantuml)
+            err << err1.to_s
+          when "plantuml-ascii-art"
+            result = ascii_art
+          end
         when "railroad", "railroad-utf8"
           result1, err1, _s = Open3.capture3("kgt -l abnf -e svg#{svg_opt}", stdin_data: result);
           result1 = svg_clean_kgt(result1); dont_clean = true
@@ -718,7 +731,7 @@ COLORS
           case t
           when "aasvg", "ditaa", "goat",
                "math", "math-asciitex", "mermaid",  "mscgen",
-               "plantuml", "plantuml-utxt",
+               "plantuml", "plantuml-utxt", "plantuml-ascii-art",
                "protocol", "protocol-aasvg", "protocol-goat",
                "railroad", "railroad-utf8"
             if gi
@@ -837,7 +850,12 @@ COLORS
         if $options.v3
           gi = el.attr.delete('gi')
           if gi && gi != 'ul'
-            "#{' '*indent}<#{gi}#{el_html_attributes(el)}>\n#{text}#{' '*indent}</#{gi}>\n"
+            if RFCXML_SPAN_ELEMENTS === gi
+              text.sub!(/\A\s*<t>(.*)<\/t>\s*\z/) {$1} # XXX unwrap inner text from block
+              "#{' '*indent}<t><#{gi}#{el_html_attributes(el)}>#{text}</#{gi}></t>\n"
+            else
+              "#{' '*indent}<#{gi}#{el_html_attributes(el)}>\n#{text}#{' '*indent}</#{gi}>\n"
+            end
           else
             "#{' '*indent}<ul#{el_html_attributes_with(el, {"empty" => 'true'})}><li>\n#{text}#{' '*indent}</li></ul>\n"
           end
@@ -876,6 +894,9 @@ COLORS
         clean = ''
         parts.each do |p|
           next if p.empty?
+          if p == "<br />"
+            p = "\u2028"        # XXX
+          end
           d = REXML::Document.new("<foo>#{p}</foo>")
           t = REXML::XPath.each(d.root, "//text()").to_a.join
           if t != p
@@ -1182,6 +1203,7 @@ COLORS
 
       KRAMDOWN_OFFLINE = ENV["KRAMDOWN_OFFLINE"]
       KRAMDOWN_REFCACHE_REFETCH = ENV["KRAMDOWN_REFCACHE_REFETCH"]
+      KRAMDOWN_REFCACHE_QUIET = ENV["KRAMDOWN_REFCACHE_QUIET"]
 
       def get_and_write_resource(url, fn)
         options = {}
@@ -1230,7 +1252,7 @@ COLORS
             message = "fetching"
             fetch_timeout = 60 # seconds; long timeout needed for Travis
           end
-          $stderr.puts "#{fn}: #{message} from #{url}"
+          $stderr.puts "#{fn}: #{message} from #{url}" unless KRAMDOWN_REFCACHE_QUIET
           if Array === url
             begin
               case url[0]
@@ -1285,9 +1307,16 @@ COLORS
          "#{XML_RESOURCE_ORG_PREFIX}/bibxml-rfcsubseries/#{name}"] # FOR NOW
       end
 
+      KRAMDOWN_REFCACHETTL = (e = ENV["KRAMDOWN_REFCACHETTL"]) ? e.to_i : 3600
+
+      KRAMDOWN_REFCACHETTL_RFC = (e = ENV["KRAMDOWN_REFCACHETTL_RFC"]) ? e.to_i : 86400*7
+      KRAMDOWN_REFCACHETTL_DOI_IANA = (e = ENV["KRAMDOWN_REFCACHETTL_DOI_IANA"]) ? e.to_i : 86400
+      KRAMDOWN_REFCACHETTL_DOI = (e = ENV["KRAMDOWN_REFCACHETTL_DOI"]) ? e.to_i : KRAMDOWN_REFCACHETTL_DOI_IANA
+      KRAMDOWN_REFCACHETTL_IANA = (e = ENV["KRAMDOWN_REFCACHETTL_IANA"]) ? e.to_i : KRAMDOWN_REFCACHETTL_DOI_IANA
+
       # [subdirectory name, cache ttl in seconds, does it provide for ?anchor=]
       XML_RESOURCE_ORG_MAP = {
-        "RFC" => ["bibxml", 86400*7, false,
+        "RFC" => ["bibxml", KRAMDOWN_REFCACHETTL_RFC, false,
                   ->(fn, n){ [name = "reference.RFC.#{"%04d" % n.to_i}.xml",
                               "https://bib.ietf.org/public/rfc/bibxml/#{name}"] }
 # was                         "https://www.rfc-editor.org/refs/bibxml/#{name}"] }
@@ -1296,10 +1325,10 @@ COLORS
                   ->(fn, n){ [fn,
                               "https://datatracker.ietf.org/doc/bibxml3/draft-#{n.sub(/\Adraft-/, '')}.xml"] }
                  ],
-        "BCP" => ["bibxml-rfcsubseries", 86400*7, false,
+        "BCP" => ["bibxml-rfcsubseries", KRAMDOWN_REFCACHETTL_RFC, false,
                   ->(fn, n){ Rfc2629::bcp_std_ref("BCP", n) }
                  ],
-        "STD" => ["bibxml-rfcsubseries", 86400*7, false,
+        "STD" => ["bibxml-rfcsubseries", KRAMDOWN_REFCACHETTL_RFC, false,
                   ->(fn, n){ Rfc2629::bcp_std_ref("STD", n) }
                  ],
         "W3C" => "bibxml4",
@@ -1315,9 +1344,10 @@ COLORS
         "NIST" => "bibxml2",
         "OASIS" => "bibxml2",
         "PKCS" => "bibxml2",
-        "DOI" => ["bibxml7", 86400, true, ->(fn, n){ ["computed-#{fn}", [:DOI, n] ] }, true # always_altproc
+        "DOI" => ["bibxml7", KRAMDOWN_REFCACHETTL_DOI, true,
+                  ->(fn, n){ ["computed-#{fn}", [:DOI, n] ] }, true # always_altproc
                  ], # emulate old 24 h cache
-        "IANA" => ["bibxml8", 86400, true], # ditto
+        "IANA" => ["bibxml8", KRAMDOWN_REFCACHETTL_IANA, true], # ditto
       }
 
       # XML_RESOURCE_ORG_HOST = ENV["XML_RESOURCE_ORG_HOST"] || "xml.resource.org"
@@ -1327,8 +1357,6 @@ COLORS
                                 "https://#{XML_RESOURCE_ORG_HOST}/public/rfc"
       KRAMDOWN_USE_TOOLS_SERVER = ENV["KRAMDOWN_USE_TOOLS_SERVER"]
 
-      KRAMDOWN_REFCACHETTL = (e = ENV["KRAMDOWN_REFCACHETTL"]) ? e.to_i : 3600
-
       KRAMDOWN_NO_TARGETS = ENV['KRAMDOWN_NO_TARGETS']
       KRAMDOWN_KEEP_TARGETS = ENV['KRAMDOWN_KEEP_TARGETS']
 
